Module: Literal
- Defined in:
- app/models/chunks/literal.rb
Overview
These are basic chunks that have a pattern and can be protected.
They are used by rendering process to prevent wiki rendering
occuring within literal areas such as and blocks
and within HTML tags.
Defined Under Namespace
Classes: AbstractLiteral, Pre, Tags